@@ -20,7 +20,7 @@ class WSGI:
                     verifier = auth[0]
                     auth = auth[1]
                     claims = auth.get('claims')
-                    location = auth.get('cookie') #Can be 'cookie' or 'header'
+                    location = auth.get('cookie') 
                     if not location:
                         location = "header"
 
@@ -64,7 +64,7 @@ class WSGI:
                     targetMimetypes = blueprint[1]
                     blueprint = blueprint[0].blueprint
                     if not request.mimetype in targetMimetypes:
-                        rsp = Response("<h1>Incorrect mimetype.</h1><p>Sodium v2.01</p>")
+                        rsp = Response("<h1>Incorrect mimetype.</h1><p>Sodium v2.20</p>")
                         rsp.headers['Content-Type'] = 'text/html' 
                         return rsp(environ, start_response)
                     if request.mimetype == "application/x-www-form-urlencoded":
